@@ -52,11 +52,12 @@ sub _menus {
             [ 'log_info',             "- Logging"         ],
             [ 'max_channels',         "- Channel history" ],
             [ 'channel_by_timestamp', "- Channel sort"    ],
+            [ 'list_size_idx',        "- Size video list"  ],
         ],
         group_directory => [
-            [ 'video_dir',     "- Main video directory"     ],
-            [ 'extractor_dir', "- Extractor directory" ],
-            [ 'channel_dir',   "- Channel directory"   ],
+            [ 'video_dir',     "- Main video directory" ],
+            [ 'extractor_dir', "- Extractor directory"  ],
+            [ 'channel_dir',   "- Channel directory"    ],
         ],
         group_file => [
             [ 'max_len_f_name',           "- Max filename length" ],
@@ -160,7 +161,18 @@ sub set_options {
                     choose( [ 'Close with ENTER' ], { prompt => 'No preferred qualities set.' } );
                 }
                 else {
-                    print_hash( $pref, { preface => ' Close with ENTER' } );
+                    my @p;
+                    push @p, ' ';
+                    for my $key ( sort keys %$pref ) {
+                        push @p, "$key:";
+                        my $c = 1;
+                        for my $line ( @{$pref->{$key}} ) {
+                            push @p, sprintf "%4d. %s\n", $c, '[' . join( ',', @$line ) . ']';
+                            $c++;
+                        }
+                        push @p, ' ';
+                    }
+                    choose( \@p, { prompt => 'Close with ENTER', layout => 3, justify => 0 } );
                 }
             }
             elsif ( $choice eq "useragent" ) {
@@ -230,6 +242,14 @@ sub set_options {
                 ];
                 _opt_choose_from_list( $opt, $choice, $prompt, $list );
             }
+            elsif ( $choice eq "list_size_idx" ) {
+                my $prompt = 'Channel/Playlist - Show';
+                my $list = [
+                    'all videos',
+                    'the latest 50 videos',
+                ];
+                _opt_choose_from_list( $opt, $choice, $prompt, $list );
+            }
             elsif ( $choice eq "extractor_dir" ) {
                 my $prompt = 'Use extractor directories';
                 my $list = [
