@@ -16,8 +16,7 @@ use Try::Tiny           qw( try catch );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
-sub HIDE_CURSOR () { "\e[?25l" }
-sub SHOW_CURSOR () { "\e[?25h" }
+use App::YTDL::Helper qw( HIDE_CURSOR SHOW_CURSOR );
 
 
 
@@ -53,8 +52,8 @@ sub wrapper_get {
 
 
 sub get_new_video_url {
-    my ( $opt, $info, $video_id ) = @_;
-    my $fmt = $info->{$video_id}{fmt};
+    my ( $opt, $info, $video_id, $fmt ) = @_;
+#    my $fmt = $info->{$video_id}{fmt};
     my $youtube_dl = which( 'youtube-dl' ) // 'youtube-dl';
     my @cmd = ( $youtube_dl );
     push @cmd, '--user-agent', $opt->{useragent} if defined $opt->{useragent};
