@@ -101,17 +101,11 @@ sub _prepare_info_hash {
     if ( $info->{$video_id}{duration} =~ /^[0-9]+\z/ ) {
         $info->{$video_id}{duration} = sec_to_time( $info->{$video_id}{duration}, 1 );
     }
-    $info->{$video_id}{duration} ||= '-:--:--';
-    if ( ! $info->{$video_id}{upload_date} ) {
-        $info->{$video_id}{upload_date} = '0000-00-00';
-    }
+    $info->{$video_id}{duration}    ||= '-:--:--';
+    $info->{$video_id}{upload_date} ||= '0000-00-00';
     if ( $info->{$video_id}{like_count} && $info->{$video_id}{dislike_count} ) {
-        if ( ! $info->{$video_id}{raters} ) {
-            $info->{$video_id}{raters} = $info->{$video_id}{like_count} + $info->{$video_id}{dislike_count};
-        }
-        if ( ! $info->{$video_id}{avg_rating} ) {
-            $info->{$video_id}{avg_rating} = $info->{$video_id}{like_count} * 5 / $info->{$video_id}{raters};
-        }
+        $info->{$video_id}{raters}     ||= $info->{$video_id}{like_count} + $info->{$video_id}{dislike_count};
+        $info->{$video_id}{avg_rating} ||= $info->{$video_id}{like_count} * 5 / $info->{$video_id}{raters};
     }
     if ( $info->{$video_id}{avg_rating} ) {
         $info->{$video_id}{avg_rating} = sprintf "%.2f", $info->{$video_id}{avg_rating};
