@@ -11,7 +11,7 @@ our @EXPORT_OK = qw( read_history_files channel_history_menu add_channel_to_hist
 use List::MoreUtils qw( none );
 use Term::Choose    qw( choose );
 
-use App::YTDL::Helper   qw( read_json write_json );
+use App::YTDL::Helper qw( read_json write_json );
 
 
 
@@ -32,12 +32,15 @@ sub read_history_files {
 
 sub channel_history_menu {
     my ( $opt ) = @_;
+    my $list_size_idx = $opt->{list_size_idx};
 
     MENU : while ( 1 ) {
+        my @list_size = ( '  ALL', '  50' );
+        my $list_size_regexp = join '|', map { quotemeta } @list_size;
         my ( $channel, $sticky ) = ( '  Channel', '  Sticky' );
         # Choose
         my $choice = choose(
-            [ undef, $channel, $sticky ],
+            [ undef, $channel, $sticky, $list_size[$list_size_idx] ],
             { prompt => 'Choose:', layout => 3, undef => '  QUIT' }
         );
         if ( ! defined $choice ) {
@@ -83,6 +86,7 @@ sub channel_history_menu {
                             $prompt .= sprintf "= %s (%s)\n", $history->[$i], $opt->{channel_history}{$history_url->[$i]}{channel_id};
                         }
                     }
+                    $opt->{nr_of_latest_videos} = $list_size[$list_size_idx] =~ /\D(\d+)/ ? $1 : 0;
                     #last MENU;
                     return @ids;
                 }
@@ -137,6 +141,11 @@ sub channel_history_menu {
                 }
             }
         }
+        if ( $choice =~ /^$list_size_regexp\z/ ) {
+            $list_size_idx++;
+            $list_size_idx = 0 if $list_size_idx > $#list_size;
+            next MENU;
+        }
     }
 }
 
